package come.stormborntales.notevault

import android.content.Context
import android.net.Uri
import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.activity.result.ActivityResultLauncher
import androidx.activity.result.PickVisualMediaRequest
import androidx.activity.result.contract.ActivityResultContracts
import androidx.compose.runtime.mutableStateListOf
import come.stormborntales.notevault.data.model.NoteEntry
import come.stormborntales.notevault.ui.screens.MainScreen
import come.stormborntales.notevault.ui.theme.NoteVaultTheme
import java.io.File
import java.io.InputStream

class MainActivity : ComponentActivity() {
    private lateinit var imagePickerLauncher: ActivityResultLauncher<PickVisualMediaRequest>
    // Definiere notes als MutableStateList für die gesamte Aktivität
    private val notes = mutableStateListOf<NoteEntry>()
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()

        // Launcher für die Bildauswahl einrichten
        imagePickerLauncher = registerForActivityResult(ActivityResultContracts.PickMultipleVisualMedia()) { uris ->
            if (!uris.isNullOrEmpty()) {
                val context: Context = applicationContext
                val copiedUris = uris.mapNotNull { uri ->
                    try {
                        val inputStream: InputStream? = contentResolver.openInputStream(uri)
                        val outputFile =
                            File(context.filesDir, "note_${System.currentTimeMillis()}_${uri.lastPathSegment}")
                        inputStream?.use { input ->
                            outputFile.outputStream().use { output ->
                                input.copyTo(output)
                            }
                        }
                        Uri.fromFile(outputFile)
                    } catch (e: Exception) {
                        e.printStackTrace()
                        null
                    }
                }

                if (copiedUris.isNotEmpty()) {
                    notes.add(NoteEntry(images = copiedUris)) // Titel optional setzen
                }
            }
        }

        setContent {
            NoteVaultTheme {
                MainScreen(
                    onAddNoteClicked = {
                        // Öffne die Galerie zum Auswählen eines Bildes
                        imagePickerLauncher.launch(PickVisualMediaRequest(ActivityResultContracts.PickVisualMedia.ImageAndVideo))
                    },
                    notes = notes,
                )
            }
        }
    }
}